Please see [https://docs.mlcommons.org/cm4mlops/scripts/CM-automation/create-custom-cache-entry](https://docs.mlcommons.org/cm4mlops/scripts/CM-automation/create-custom-cache-entry) for the documentation of this CM script.
